@@ -335,16 +335,17 @@ void yaspot_glue_del_state_cb(yaspot_glue_t *t, yaspot_glue_state_changed_t call
     g_assert(t);
     g_assert(callback);
 
-    for (i = g_list_first(t->state_cb); i != g_list_last(t->state_cb); i = g_list_next(i)) {
+    i = g_list_first(t->state_cb);
+    do {
         s = (state_callback_t*)i->data;
 
         if (s && s->state_cb == callback && s->state_cb_data == userdata) {
-            g_print("found state callback data to delete.\n");
+            g_print("del state cb %p data %p\n", callback, userdata);
             t->state_cb = g_list_remove_link(t->state_cb, i);
             g_free(s);
             break;
         }
-    }
+    } while ((i = g_list_next(i)));
 }
 
 void yaspot_glue_set_timer_cb(yaspot_glue_t *t, yaspot_glue_timer_update_t callback, gpointer userdata) {
@@ -1151,5 +1152,27 @@ gchar* yaspot_glue_current_track(yaspot_glue_t *t) {
     return response;
 }
 
+gint yaspot_glue_current_track_num(yaspot_glue_t *t) {
+    gint response = -1;
+    struct track *tr;
+    gint i;
+
+    g_assert(t);
+
+    g_static_rw_lock_reader_lock(&data_lock);
+
+    if (t->current) {
+        i = 1;
+
+        for (tr = t->current->tracks; tr != t->current_track; tr = tr->next)
+            i++;
+
+        response = i;
+    }
+    g_static_rw_lock_reader_unlock(&data_lock);
+
+    return response;
+}
+
 // vim: expandtab
 
